@@ -210,11 +210,7 @@ def type_sorting_key(t):
     if t is None or t is type(None):
         return (-1, repr(t))
     t = get_origin(t) or t
-    try:
-        is_container = int(issubclass(t, collections.abc.Container))
-    except Exception:  # pragma: no cover
-        # e.g. `typing_extensions.Literal` is not a container
-        is_container = 0
+    is_container = int(try_issubclass(t, collections.abc.Container))
     return (is_container, repr(t))
 
 
@@ -228,7 +224,7 @@ def _compatible_args(args, superclass_args):
         # good enough for all the cases that I've seen so far and has the
         # substantial virtue of (relative) simplicity.
         a == b or isinstance(a, typing.TypeVar) or isinstance(b, typing.TypeVar)
-        for a, b in zip(args, superclass_args)
+        for a, b in zip(args, superclass_args, strict=True)
     )
 
 
@@ -272,14 +268,36 @@ def is_a_new_type(thing):
     return isinstance(thing, typing.NewType)
 
 
+def is_a_type_alias_type(thing):  # pragma: no cover # covered by 3.12+ tests
+    # TypeAliasType is new in python 3.12, through the type statement. If we're
+    # before python 3.12 then this can't possibly by a TypeAliasType.
+    #
+    # https://docs.python.org/3/reference/simple_stmts.html#type
+    # https://docs.python.org/3/library/typing.html#typing.TypeAliasType
+    if sys.version_info < (3, 12):
+        return False
+    return isinstance(thing, typing.TypeAliasType)
+
+
 def is_a_union(thing: object) -> bool:
     """Return True if thing is a typing.Union or types.UnionType (in py310)."""
     return isinstance(thing, UnionType) or get_origin(thing) is typing.Union
 
 
 def is_a_type(thing: object) -> bool:
-    """Return True if thing is a type or a generic type like thing."""
-    return isinstance(thing, type) or is_generic_type(thing) or is_a_new_type(thing)
+    """
+    Return True if thing is a type or a typing-like thing (union, generic type, etc).
+    """
+    return (
+        isinstance(thing, type)
+        or is_generic_type(thing)
+        or is_a_new_type(thing)
+        or is_a_type_alias_type(thing)
+        # union and forwardref checks necessary from 3.14+. Before 3.14, they
+        # were covered by is_generic_type(thing).
+        or is_a_union(thing)
+        or isinstance(thing, typing.ForwardRef)
+    )
 
 
 def is_typing_literal(thing: object) -> bool:
@@ -436,7 +454,7 @@ def _try_import_forward_ref(thing, typ, *, type_params):  # pragma: no cover
 
 
 def from_typing_type(thing):
-    # We start with Final, Literal, and Annotated since they don't support `isinstance`.
+    # We start with Final, Literal, and Annotated, since they don't support `isinstance`.
     #
     # We then explicitly error on non-Generic types, which don't carry enough
     # information to sensibly resolve to strategies at runtime.
@@ -490,6 +508,7 @@ def from_typing_type(thing):
     if len(mapping) > 1:
         _Environ = getattr(os, "_Environ", None)
         mapping.pop(_Environ, None)
+
     tuple_types = [
         t
         for t in mapping
@@ -504,10 +523,40 @@ def from_typing_type(thing):
         # to fail, due to weird isinstance behaviour around the elements.
         mapping.pop(collections.abc.ItemsView, None)
         mapping.pop(typing.ItemsView, None)
-    if {collections.deque}.intersection(mapping) and len(mapping) > 1:
+    if collections.deque in mapping and len(mapping) > 1:
         # Resolving generic sequences to include a deque is more trouble for e.g.
         # the ghostwriter than it's worth, via undefined names in the repr.
-        mapping.pop(collections.deque, None)
+        mapping.pop(collections.deque)
+
+    if (
+        memoryview in mapping
+        and getattr(thing, "__args__", None)
+        and not hasattr(thing.__args__[0], "__buffer__")
+    ):  # pragma: no cover  # covered by 3.14+
+        # Both memoryview and list are direct subclasses of Sequence. If we ask for
+        # st.from_type(Sequence[A]), we will get both list[A] and memoryview[A].
+        # But unless A implements the buffer protocol with __buffer__, resolving
+        # memoryview[A] will error.
+        #
+        # Since the user didn't explicitly ask for memoryview, there's no reason
+        # to expect them to have implemented __buffer__. Remove memoryview in this
+        # case, before it can fail at resolution-time.
+        #
+        # Note: I intentionally did not add a `and len(mapping) > 1` condition here.
+        # If memoryview[A] is the only resolution for a strategy, but A is not a
+        # buffer protocol, our options are to (1) pop memoryview and raise
+        # ResolutionFailed, or (2) to keep memoryview in the mapping and error in
+        # resolve_memoryview. A failure in test_resolving_standard_contextmanager_as_generic
+        # (because memoryview is a context manager in 3.14) convinced me the former
+        # was less confusing to users.
+        mapping.pop(memoryview)
+
+    elem_type = (getattr(thing, "__args__", None) or ["not int"])[0]
+    union_elems = elem_type.__args__ if is_a_union(elem_type) else ()
+    allows_integer_elements = any(
+        isinstance(T, type) and try_issubclass(int, get_origin(T) or T)
+        for T in [*union_elems, elem_type]
+    )
 
     if len(mapping) > 1:
         # issubclass treats bytestring as a kind of sequence, which it is,
@@ -519,15 +568,7 @@ def from_typing_type(thing):
         # This block drops bytes from the types that can be generated
         # if there is more than one allowed type, and the element type is
         # not either `int` or a Union with `int` as one of its elements.
-        elem_type = (getattr(thing, "__args__", None) or ["not int"])[0]
-        if is_a_union(elem_type):
-            union_elems = elem_type.__args__
-        else:
-            union_elems = ()
-        if not any(
-            isinstance(T, type) and issubclass(int, get_origin(T) or T)
-            for T in [*union_elems, elem_type]
-        ):
+        if not allows_integer_elements:
             mapping.pop(bytes, None)
             if sys.version_info[:2] <= (3, 13):
                 mapping.pop(collections.abc.ByteString, None)
@@ -537,16 +578,51 @@ def from_typing_type(thing):
         and thing.__forward_arg__ in vars(builtins)
     ):
         return st.from_type(getattr(builtins, thing.__forward_arg__))
+
+    def is_maximal(t):
+        # For each k in the mapping, we use it if it's the most general type
+        # available, and exclude any more specific types. So if both
+        # Sequence and Collection are available, we use the most general Collection
+        # type.
+        #
+        # k being "the most general" is equivalent to saying that k is maximal
+        # in the partial ordering of types. Note that since the ordering is
+        # partial there may be multiple maximal elements. (This distinguishes
+        # maximal from maximum).
+        return sum(try_issubclass(t, T) for T in mapping) == 1
+
+    strategies = [
+        (t, s if isinstance(s, st.SearchStrategy) else s(thing))
+        for t, s in mapping.items()
+        if is_maximal(t)
+    ]
+    strategies = [(t, s) for t, s in strategies if s != NotImplemented]
+
+    # 3.14+ removes typing.ByteString. typing.ByteString was the only reason we
+    # previously generated bytes for Sequence[int]. There is no equivalent
+    # for typing.ByteString in 3.14+, but we would still like to generate bytes
+    # for Sequence[int] and its supertypes. Special case that here.
+    if (
+        sys.version_info[:2] >= (3, 14)
+        and allows_integer_elements
+        # For the same reason as the is_maximal check above, we only include
+        # this ByteString special case if it is not overridden by a more general
+        # available type.
+        #
+        # collections.abc.ByteString was a direct subclass of Sequence, so we
+        # use that as the standin type when checking. Note we compare to a count
+        # of 0, instead of 1, since in is_maximal `k` is already in `mapping`,
+        # and we expect `try_issubclass(k, k) == True`.
+        and try_issubclass(collections.abc.Sequence, thing)
+        and sum(try_issubclass(collections.abc.Sequence, T) for T in mapping) == 0
+    ):  # pragma: no cover  # covered on 3.14+
+        strategies.append((collections.abc.Sequence, st.binary()))
+
     # Sort strategies according to our type-sorting heuristic for stable output
     strategies = [
-        s
-        for s in (
-            v if isinstance(v, st.SearchStrategy) else v(thing)
-            for k, v in sorted(mapping.items(), key=lambda kv: type_sorting_key(kv[0]))
-            if sum(try_issubclass(k, T) for T in mapping) == 1
-        )
-        if s != NotImplemented
+        s for _k, s in sorted(strategies, key=lambda kv: type_sorting_key(kv[0]))
     ]
+
     empty = ", ".join(repr(s) for s in strategies if s.is_empty)
     if empty or not strategies:
         raise ResolutionFailed(
@@ -592,7 +668,7 @@ utc_offsets = st.builds(
 # returned without being listed in a function signature:
 # https://github.com/python/mypy/issues/6710#issuecomment-485580032
 _global_type_lookup: dict[
-    type, typing.Union[st.SearchStrategy, typing.Callable[[type], st.SearchStrategy]]
+    type, st.SearchStrategy | typing.Callable[[type], st.SearchStrategy]
 ] = {
     type(None): st.none(),
     bool: st.booleans(),
@@ -620,7 +696,6 @@ _global_type_lookup: dict[
     type(Ellipsis): st.just(Ellipsis),
     type(NotImplemented): st.just(NotImplemented),
     bytearray: st.binary().map(bytearray),
-    memoryview: st.binary().map(memoryview),
     numbers.Real: st.floats(),
     numbers.Rational: st.fractions(),
     numbers.Number: st.complex_numbers(),
@@ -705,13 +780,15 @@ _fallback_type_strategy = st.sampled_from(
 # includes this... but we don't actually ever want to build one.
 _global_type_lookup[os._Environ] = st.just(os.environ)
 
-if sys.version_info[:2] <= (3, 13):
+if sys.version_info[:2] < (3, 14):
     # Note: while ByteString notionally also represents the bytearray and
     # memoryview types, it is a subclass of Hashable and those types are not.
     # We therefore only generate the bytes type. type-ignored due to deprecation.
     _global_type_lookup[typing.ByteString] = st.binary()  # type: ignore
     _global_type_lookup[collections.abc.ByteString] = st.binary()  # type: ignore
 
+    _global_type_lookup[memoryview] = st.binary().map(memoryview)
+
 
 _global_type_lookup.update(
     {
@@ -775,16 +852,14 @@ _global_type_lookup.update(
 # installed. To avoid the performance hit of importing anything here, we defer
 # it until the method is called the first time, at which point we replace the
 # entry in the lookup table with the direct call.
-def _from_numpy_type(thing: type) -> typing.Optional[st.SearchStrategy]:
+def _from_numpy_type(thing: type) -> st.SearchStrategy | None:
     from hypothesis.extra.numpy import _from_type
 
     _global_extra_lookup["numpy"] = _from_type
     return _from_type(thing)
 
 
-_global_extra_lookup: dict[
-    str, typing.Callable[[type], typing.Optional[st.SearchStrategy]]
-] = {
+_global_extra_lookup: dict[str, typing.Callable[[type], st.SearchStrategy | None]] = {
     "numpy": _from_numpy_type,
 }
 
@@ -822,9 +897,7 @@ def register(type_, fallback=None, *, module=typing):
 @register("Type")
 @register("Type", module=typing_extensions)
 def resolve_Type(thing):
-    if getattr(thing, "__args__", None) is None:
-        return st.just(type)
-    elif get_args(thing) == ():  # pragma: no cover
+    if getattr(thing, "__args__", None) is None or get_args(thing) == ():
         return _fallback_type_strategy
     args = (thing.__args__[0],)
     if is_a_union(args[0]):
@@ -933,7 +1006,7 @@ def resolve_Iterator(thing):
     return st.iterables(st.from_type(thing.__args__[0]))
 
 
-@register(typing.Counter, st.builds(collections.Counter))
+@register(collections.Counter, st.builds(collections.Counter))
 def resolve_Counter(thing):
     return st.dictionaries(
         keys=st.from_type(thing.__args__[0]),
@@ -941,17 +1014,17 @@ def resolve_Counter(thing):
     ).map(collections.Counter)
 
 
-@register(typing.Deque, st.builds(collections.deque))
+@register(collections.deque, st.builds(collections.deque))
 def resolve_deque(thing):
     return st.lists(st.from_type(thing.__args__[0])).map(collections.deque)
 
 
-@register(typing.ChainMap, st.builds(dict).map(collections.ChainMap))
+@register(collections.ChainMap, st.builds(dict).map(collections.ChainMap))
 def resolve_ChainMap(thing):
     return resolve_Dict(thing).map(collections.ChainMap)
 
 
-@register(typing.OrderedDict, st.builds(dict).map(collections.OrderedDict))
+@register(collections.OrderedDict, st.builds(dict).map(collections.OrderedDict))
 def resolve_OrderedDict(thing):
     return resolve_Dict(thing).map(collections.OrderedDict)
 
@@ -981,12 +1054,13 @@ def resolve_Match(thing):
 
 class GeneratorStrategy(st.SearchStrategy):
     def __init__(self, yields, returns):
+        super().__init__()
         assert isinstance(yields, st.SearchStrategy)
         assert isinstance(returns, st.SearchStrategy)
         self.yields = yields
         self.returns = returns
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<generators yields={self.yields!r} returns={self.returns!r}>"
 
     def do_draw(self, data):
@@ -1033,6 +1107,9 @@ def resolve_Callable(thing):
             "Consider using an explicit strategy, or opening an issue."
         )
 
+    if get_origin(thing) is collections.abc.Callable and return_type is None:
+        return_type = type(None)
+
     return st.functions(
         like=(lambda *a, **k: None) if args_types else (lambda: None),
         returns=st.from_type(return_type),
@@ -1084,3 +1161,13 @@ def resolve_TypeVar(thing):
         ),
         key=type_var_key,
     ).flatmap(st.from_type)
+
+
+if sys.version_info[:2] >= (3, 14):
+    # memoryview is newly generic in 3.14. see
+    # https://github.com/python/cpython/issues/126012
+    # and https://docs.python.org/3/library/stdtypes.html#memoryview
+
+    @register(memoryview, st.binary().map(memoryview))
+    def resolve_memoryview(thing):
+        return st.from_type(thing.__args__[0]).map(memoryview)
